@@ -3,7 +3,6 @@
 if((inherits(x, "PCA") | inherits(x, "MCA") | inherits(x, "CA")| inherits(x, "FAMD")| inherits(x, "MFA"))){
   resultsHCPCshiny <- x
   anafact <- lignecodeHCPCshiny
-  resClusHCPCshiny <- HCPC(resultsHCPCshiny,nb.clust=-1,graph=FALSE)$call$t$nb.clust
   if (inherits(x, "CA")){
     nbindivHCPCshiny <- nrow(resultsHCPCshiny$row$coord)
     nbcolHCPCshiny <- ncol(resultsHCPCshiny$row$coord)
@@ -13,12 +12,17 @@ if((inherits(x, "PCA") | inherits(x, "MCA") | inherits(x, "CA")| inherits(x, "FA
     nbcolHCPCshiny <- ncol(resultsHCPCshiny$ind$coord)
     clusterOnCA <- NULL
   }
+  if (nbindivHCPCshiny>100) resClusHCPCshiny <- HCPC(resultsHCPCshiny,kk=100,nb.clust=-1,graph=FALSE)$call$t$nb.clust
+  else resClusHCPCshiny <- HCPC(resultsHCPCshiny,nb.clust=-1,graph=FALSE)$call$t$nb.clust
   clustdfHCPCshiny <- resClusHCPCshiny
   consolidfHCPCshiny <- FALSE
   metricdfHCPCshiny <- gettext("Euclidean",domain="R-Factoshiny")
   drawdfHCPCshiny <- FALSE
   dfHCPCshiny <- FALSE
   centerdfHCPCshiny <- FALSE
+  if (nbindivHCPCshiny>100) kkparamInit <- TRUE
+  else kkparamInit <- FALSE
+  kkInit <- min(100,nbindivHCPCshiny-1)
   numdfHCPCshiny <- 60
   nb1dfHCPCshiny <- 1
   nb2dfHCPCshiny <- 2
@@ -44,6 +48,8 @@ title1HCPCshiny <- x$title1HCPCshiny
 title2HCPCshiny <- x$title2HCPCshiny
 title3HCPCshiny <- x$title3HCPCshiny
 clusterOnCA <- x$clusterOnCA
+kkInit <- x$kk
+kkparamInit <- x$kkparam
 }
 
 if(inherits(x, "PCAshiny") | inherits(x, "CAshiny") | inherits(x, "MCAshiny") | inherits(x, "FAMDshiny")| inherits(x, "MFAshiny")){
@@ -57,7 +63,11 @@ if(inherits(x, "PCAshiny") | inherits(x, "CAshiny") | inherits(x, "MCAshiny") |
     nbcolHCPCshiny <- ncol(resultsHCPCshiny$ind$coord)
     clusterOnCA <- NULL
   }
-  resClusHCPCshiny=HCPC(resultsHCPCshiny,nb.clust=-1,graph=FALSE)$call$t$nb.clust
+  if (nbindivHCPCshiny>100) resClusHCPCshiny <- HCPC(resultsHCPCshiny,kk=100,nb.clust=-1,graph=FALSE)$call$t$nb.clust
+  else resClusHCPCshiny <- HCPC(resultsHCPCshiny,nb.clust=-1,graph=FALSE)$call$t$nb.clust
+  if (nbindivHCPCshiny>100) kkparamInit <- TRUE
+  else kkparamInit <- FALSE
+  kkInit <- min(100,nbindivHCPCshiny-1)
   clustdfHCPCshiny=resClusHCPCshiny
   consolidfHCPCshiny=FALSE
   metricdfHCPCshiny=gettext("Euclidean",domain="R-Factoshiny")
@@ -96,10 +106,10 @@ if(inherits(x, "HCPC")){
   title2HCPCshiny <- gettext("Factor map",domain="R-Factoshiny")
   title3HCPCshiny <- gettext("Hierarchical tree",domain="R-Factoshiny")
 }
-
 # if(!(inherits(x, "HCPC") | inherits(x, "HCPCshiny"))) resClusHCPCshiny <- HCPC(resultsHCPCshiny,nb.clust=-1,graph=FALSE)$call$t$nb.clust
 # if (inherits(x, "CA")) nbindivHCPCshiny=nrow(resultsHCPCshiny$row$coord)
 # else nbindivHCPCshiny=nrow(resultsHCPCshiny$ind$coord)
 # if (inherits(x, "CA")) nbcolHCPCshiny <- ncol(resultsHCPCshiny$row$coord)
 # else nbcolHCPCshiny <- ncol(resultsHCPCshiny$ind$coord)
 }
+pvalueDimdescInit <- 0.05
